from django.apps import AppConfig


class DjangoInstagramConfig(AppConfig):
    default_auto_field = "django.db.models.BigAutoField"
    name = "instagram_sync.contrib.django"
    label = "instagram_sync"
