# Generated by Django 4.0 on 2022-08-22 04:42

import encrypted_model_fields.fields
from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = []

    operations = [
        migrations.CreateModel(
            name="InstagramAccount",
            fields=[
                (
                    "account_id",
                    models.PositiveBigIntegerField(primary_key=True, serialize=False),
                ),
                ("access_token", encrypted_model_fields.fields.EncryptedCharField()),
                ("authorized_on", models.DateTimeField(auto_now_add=True)),
            ],
            options={
                "verbose_name_plural": "Instagram Accounts",
                "db_table": "instagram_account",
            },
        ),
    ]
